/**
 * @(#)Quake2PakDirectoryEntry
 *
 * Contains the information of a single directory entry.
 *
 */

package blackmane.quake2.pak;
 
public class Quake2PakDirectoryEntry {
	// the data of the directory entry.
	protected byte[]	internalName;
	protected int filePosition;
	protected int fileLength;
	
	/**
	 * creates a directory entry with the specified name, offset and length.
	 *
	 * @param name name of the file as bytes (56 bytes)
	 * @param pos offset of the file's data in the pak file
	 * @param length length of the file in the pak file.
	 */
	public Quake2PakDirectoryEntry(byte[] name, int pos, int length) {
		internalName = name;
		filePosition = pos;
		fileLength = length;
	}
	
	/**
   * Chops up the internal name to get rid of any 0 bytes at the end,
   * and returns it as a nice String.
   *
   * @return a String containing the chopped up name.
	 */
	public String choppedName() {
		String chopped = new String(internalName);
		// may have some 0 bytes at the end, so get rid of them
		chopped = chopped.substring(0, chopped.indexOf(0));
		
		return chopped;
	}
	
	/**
	 * Returns the fill internal name, 0 bytes and all
	 *
	 * @return the full internal name, which may contain 0 bytes at the end.
	 */
	public byte[] name() {
		return internalName;
	}
	
	/*
	 * Returns the file position of the data of this entry.
	 *
	 * @return the offset of the file in the pak file.
	 */
	public int position() {
		return filePosition;
	}
	
	/*
	 * Returns the length of the data of this entry.
	 *
	 * @return the length of the file in the pak file.
	 */
	public int length() {
		return fileLength;
	}
}