/**
 * @(#)Quake2PakHeader
 *
 * Basically a data structure for the Quake 2 Pak Header
 * information. Contains a couple of functions for verification
 * and other stuff.
 *
 * This is part of blackmane.quake2.pak
 *
 */
 
package blackmane.quake2.pak;
 
public class Quake2PakHeader {
	// the magic number for the header that tells us this is
	// a quake2 pak file.
	public static final int MAGIC = (('K'<<24)+('C'<<16)+('A'<<8)+'P');
	
	// the actual items in the header
	// REMEMBER: Quake 2 uses intel-style ints so we need to use
	// IntegerUtility.intSwap to read these three numbers in.
	protected int magic;
	protected int directory_offset;
	protected int directory_length;
	
	/**
	 * @param m the magic number
	 * @param o the offset of the directory
	 * @param l the length of the directory
	 */
	Quake2PakHeader(int m, int o, int l) {
		magic = m;
		directory_offset = o;
		directory_length = l;
	}
	
	/**
	 * This uses the pak magic number rather than a program-supplied one.
	 * @param o the offset of the directory
	 * @param l the length of the directory
	 */
	Quake2PakHeader(int o, int l) {
		this(MAGIC, o, l);
	}
	
	/**
	 * To determine whether this is a valid Pak file, using
	 * the magic number.
	 * @return <code>true</code> if the magic number is correct;
	 *         <code>false</code> otherwise.
	 */
	public boolean validPak() {
		return magic == MAGIC;
	}
	
	/**
	 * Returns the offset of the directory information.
	 * @return the offset of the directory.
	 */
	public int directoryOffset() {
		return directory_offset;
	}
	
	/**
	 * Returns the length of the directory information.
	 * @return the length of the directory
	 */
	public int directoryLength() {
		return directory_length;
	}
	
	/**
	 * @return the magic number
	 */
	public int magic() {
		return magic;
	}
}
	